@@ -9,6 +9,7 @@ from __future__ import annotations
 import logging
 import os
 import typing
+import warnings
 from collections.abc import Collection
 from functools import partial
 
@@ -437,7 +438,6 @@ class BuildingBlock(Molecule):
                 types are:
 
                     #. ``.mol``, ``.sdf`` - MDL V3000 MOL file
-                    #. ``.pdb`` - PDB file
 
             functional_groups:
                 An :class:`iterable` of :class:`.FunctionalGroup` or
@@ -484,6 +484,15 @@ class BuildingBlock(Molecule):
 
         _, extension = os.path.splitext(path)
 
+        if extension == '.pdb':
+            warnings.warn(
+                'Loading from .pdb files is deprecated and will be '
+                'removed from stk versions released after 1st Nov '
+                '2022. Please use .mol files for loading molecules '
+                'instead.',
+                category=FutureWarning,
+            )
+
         if extension not in cls._init_funcs:
             raise ValueError(
                 f'Unable to initialize from "{extension}" files.'
